@@ -1,3 +1,3 @@
-setGeneric("RVsharing", function(data, dad.id, mom.id) standardGeneric("RVsharing"))
+setGeneric("RVsharing", function(data, dad.id, mom.id,carriers) standardGeneric("RVsharing"))
 setGeneric("GeneDrop", function(trio, geno.vec ) standardGeneric("GeneDrop"))
 setGeneric("ComputeKinshipPropCoef", function(obj ) standardGeneric("ComputeKinshipPropCoef"))
\ No newline at end of file
